==> 4.7.4.tar.gz: terraform-provider-decort/wiki/4.5.3/06.01.40-Data_decort_disk_list_types_detailed.md <==
Функция доступна в провайдере версии 3.2 и выше.

_Data source_ функция **decort_disk_list_types_detailed** служит для получения расширенной информации о поддерживаемых платформой типах дисков. В отличии от другой _data source_ функции **decort_disk_list_types**, данная функция позволяет получить информацию о поддерживаемых пулами и sep типов дисков.

## Аргументы
_Data source_ функция **decort_disk_list_types_detailed** принимает следующие аргументы:

| Аргумент | Тип | Обязательный | Описание |
| --- | --- | --- | --- | 
| page | int | :x: | Номер страниц |
| size | int | :x: | Размер страницы |

## Возвращаемые значения
В случае успешного выполнения _data source_ функция **decort_disk_list_types_detailed** возвращает в указанную при вызове переменную, в поле _items_, массив, каждый элемент которого состоит из следующих параметров:

| Параметр | Тип | Описание |
| --- | --- | --- |
| pools | []Struct см.ниже | Пул хранилища |
| sep_id | int | ID storage endpoint (SEP). SEP это способ идентифицировать конкретную систему хранения, на ресурсах которой размещён данный диск |
| sep_name | int | Имя storage endpoint |

### Описание структуры pool
| Параметр | Тип | Описание |
| --- | --- | --- |
| name | string | Имя пул |
| system | string | Флаг, обозначающий служебный пул, для размещения там данных о блокировках |
| types | []string | Список поддерживаемых типов |

## Пример использования
Пример вызова _data source_ функции **decort_disk_list_types_detailed*:
```terraform
data "decort_disk_list_types_detailed" "dtd" {
  #Нет входных параметров

  #номер страницы для отображения
  #опциональный параметр
  #тип - число
  #если не задан - выводятся все доступные данные
  #page = 2

  #размер страницы
  #опциональный параметр
  #тип - число
  #если не задан - выводятся все доступные данные
  #size = 3
}

```

После успешного завершения такого вызова **decort_disk_list_types_detailed** в переменной `data.decort_disk_list_types_detailed.dtd` будут сохранены возвращаемые значения.

==> 4.9.0.tar.gz: terraform-provider-decort/wiki/4.6.3/06.01.40-Data_decort_disk_list_types_detailed.md <==
Функция доступна в провайдере версии 3.2 и выше.

_Data source_ функция **decort_disk_list_types_detailed** служит для получения расширенной информации о поддерживаемых платформой типах дисков. В отличии от другой _data source_ функции **decort_disk_list_types**, данная функция позволяет получить информацию о поддерживаемых пулами и sep типов дисков.

## Аргументы
_Data source_ функция **decort_disk_list_types_detailed** принимает следующие аргументы:

| Аргумент | Тип | Обязательный | Описание |
| --- | --- | --- | --- | 
| sort_by | string | :x: | Фильтр по одному из поддерживаемых полей, формат: +или- название поля |
| page | int | :x: | Номер страниц |
| size | int | :x: | Размер страницы |

## Возвращаемые значения
В случае успешного выполнения _data source_ функция **decort_disk_list_types_detailed** возвращает в указанную при вызове переменную, в поле _items_, массив, каждый элемент которого состоит из следующих параметров:

| Параметр | Тип | Описание |
| --- | --- | --- |
| pools | []Struct см.ниже | Пул хранилища |
| sep_id | int | ID storage endpoint (SEP). SEP это способ идентифицировать конкретную систему хранения, на ресурсах которой размещён данный диск |
| sep_name | int | Имя storage endpoint |

### Описание структуры pool
| Параметр | Тип | Описание |
| --- | --- | --- |
| name | string | Имя пул |
| system | string | Флаг, обозначающий служебный пул, для размещения там данных о блокировках |
| types | []string | Список поддерживаемых типов |

## Пример использования
Пример вызова _data source_ функции **decort_disk_list_types_detailed*:
```terraform
data "decort_disk_list_types_detailed" "dltd" {
  #сортировка по одному из поддерживаемых полей
  #опциональный параметр
  #тип - строка
  #формат - "+поле" по возрастанию / "-поле" по убыванию
  #sort_by = "+name"

  #номер страницы для отображения
  #опциональный параметр
  #тип - целое число
  #если не задан - выводятся все доступные данные
  #page = 2

  #размер страницы
  #опциональный параметр
  #тип - целое число
  #если не задан - выводятся все доступные данные
  #size = 3
}
```

После успешного завершения такого вызова **decort_disk_list_types_detailed** в переменной `data.decort_disk_list_types_detailed.dltd` будут сохранены возвращаемые значения.
